@@ -258,10 +258,10 @@ int timsyn_play_some_data(void){
 DWORD WINAPI threadfunc(LPVOID lpV){
 	while(stop_thread == 0){
 		Sleep(1);
-		EnterCriticalSection(&mim_section);
+		//EnterCriticalSection(&mim_section);
 		timsyn_play_some_data();
 		rtsyn_play_calculate();
-		LeaveCriticalSection(&mim_section);
+		//LeaveCriticalSection(&mim_section);
 	}
 	stop_thread=0;
 	ExitThread(TRUE);
@@ -283,6 +283,7 @@ DWORD WINAPI threadfunc2(LPVOID lpV){
 			rtsyn_init();
 			hThread=CreateThread(NULL,0,threadfunc,0,0,&ThreadID);
 			SetPriorityClass(hThread, REALTIME_PRIORITY_CLASS);
+			SetThreadPriority(hThread, THREAD_PRIORITY_BELOW_NORMAL);
 			opend = 1;
 		}
 		for(i = 0 ; i < 2 ; i++) free(argv[i]);
@@ -308,6 +309,7 @@ STDAPI_(LONG) modMessage(UINT uDeviceID, UINT uMsg, DWORD dwUser, DWORD dwParam1
 	
 	MIDIHDR *IIMidiHdr;	
 	UINT evbpoint;
+	static DWORD processPriority;
 	
 	int exlen = 0;
 	char *sysexbuffer = NULL ;
@@ -317,9 +319,14 @@ STDAPI_(LONG) modMessage(UINT uDeviceID, UINT uMsg, DWORD dwUser, DWORD dwParam1
 	case MODM_OPEN:
 		OpenCount++;
 		if ( OpenCount == 1 && modm_closed  == 1 ){
+			processPriority = GetPriorityClass(GetCurrentProcess());
+			SetPriorityClass(GetCurrentProcess(), REALTIME_PRIORITY_CLASS);
 			hRtsynThread=CreateThread(NULL,0,threadfunc2,0,0,&ThreadID);
 			modm_closed = 0;
 		}
+		
+	
+		SetPriorityClass(GetCurrentProcess(), processPriority);
 		return MMSYSERR_NOERROR;
 		break;
 	case MODM_PREPARE:
@@ -381,6 +388,7 @@ STDAPI_(LONG) modMessage(UINT uDeviceID, UINT uMsg, DWORD dwUser, DWORD dwParam1
 			stop_thread = 0;
 			CloseHandle(hRtsynThread);
 			CloseHandle(hCalcThread);
+			SetPriorityClass(GetCurrentProcess(), processPriority);
 			modm_closed=1;
 		}else{ 
 			if(OpenCount < 0){
